ModuleReader class

Support for reading and parsing constant Modules into data structures.

Constructors

ModuleReader({ProviderReader providerReader = const ProviderReader()})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

deduplicateProviders(Iterable<ProviderElement> providers) → List<ProviderElement>
Returns a unique ordered-set based off of providers.
extractProviderObjects(DartObject? value) → Iterable<DartObject>
Helper method that can recursively extract DartObjects for Provider.
isList(DartObject o) → bool
Returns whether an object represents a constant List.
isModule(DartObject o) → bool
Returns whether an object is abstractly a "module" of providers.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
parseModule(DartObject o) → ModuleElement
Parses a static object representing a Module.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited