ReflectableOutput class

Constructors

ReflectableOutput({List<String> urlsNeedingInitReflector = const [], Map<String, String> conditionalVariants = const {}, List<ReflectableClass> registerClasses = const [], List<DependencyInvocation<ExecutableElement>> registerFunctions = const []})
const

Properties

conditionalVariants Map<String, String>
Maps a browser .template.dart URI to its native/VM .template.dart counterpart, for files that use a conditional export (export 'a_browser.dart' if (dart.library.io) 'a_vm.dart').
final
hashCode int
The hash code for this object.
no setteroverride
registerClasses List<ReflectableClass>
What class elements require registration in initReflector.
final
registerFunctions List<DependencyInvocation<ExecutableElement>>
What factory functions require registration in initReflector.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
urlsNeedingInitReflector List<String>
What .template.dart files need to be imported and linked to this file.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
override