Messages class abstract

Defines common messages to use during compilation.

Implementers

Constructors

Messages.base()
const

Properties

analysisFailureReasons → String
Possible reasons that static analysis/the compiler failed.
no setter
hashCode → int
The hash code for this object.
no setterinherited
optionalDependenciesNullable → String
An explanation that optional dependencies are expected to be nullable.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
urlFileBugs → String
What URL should be used for filing bugs when the compiler fails.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeGlobalSingletonService(String service) → String
Returns a message that the following global singleton service should be removed from injector or providers.
toString() → String
A string representation of this object.
inherited
unresolvedSource(Iterable<SourceSpanMessageTuple> tuples, {required String reason}) → String
Returns a message that the following sourceSpans were unresolvable.
warningForOnPushCompatibility(String name) → String
What message should be used for OnPush compatibility warnings.

Operators

operator ==(Object other) → bool
The equality operator.
inherited