CompileFactoryMetadata class

Implemented types

Constructors

CompileFactoryMetadata({required String name, String? moduleUrl, String? prefix, bool emitPrefix = false, List<CompileDiDependencyMetadata> diDeps = const []})

Properties

analyzedClass → AnalyzedClass?
If this identifier refers to a class declaration, this is non-null.
no setteroverride
diDeps → List<CompileDiDependencyMetadata>
final
emitPrefix → bool
final
hashCode → int
The hash code for this object.
no setterinherited
identifier → CompileIdentifierMetadata
no setteroverride
moduleUrl → String?
final
name → String
final
prefix → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
typeArguments → List<OutputType>
no setteroverride
value → Object
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited