LiteralList class

Represents a list literal expression.

// ['/guide', '/home']
LiteralList([
  LiteralPrimitive('/guide'),
  LiteralPrimitive('/home'),
])
Inheritance

Constructors

LiteralList(List<AST> elements)

Properties

elements List<AST>
Elements of the list.
final
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
visit<R, C, CO extends C>(AstVisitor<R, C?> visitor, [CO? context]) → R
Given a visitor and optionally a context, produce a return value R.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited