RenderNodeUpdateHelpers class
Identifiers for RenderNode-based update helpers (SSR template compiler).
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- updateRenderAttribute → CompileIdentifierMetadata
-
updateRenderAttribute(node, name, value).
final
- updateRenderClass → CompileIdentifierMetadata
-
updateRenderClass(node, className, enabled).
final
- updateRenderStyle → CompileIdentifierMetadata
-
updateRenderStyle(node, name, value).
final
- updateRenderTabIndex → CompileIdentifierMetadata
-
updateRenderTabIndex(node, value).
final