Component class
The core reusable UI building blocks for an application.
- Implemented types
Constructors
Properties
- encapsulation → ViewEncapsulation
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- renderMode → RenderMode
-
Controls how this component is rendered (SSR, CSR, or automatic).
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
styles
→ List<
String> -
final
-
styleUrls
→ List<
String> -
final
-
views
→ List<
View> -
final
Methods
-
accept<
R, C, CO extends C> (IRVisitor< R, C> visitor, [CO? context]) → R -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited