BoundDirectiveEventAst class

An event binding that matches an @Output declared on the directive.

These can be either event handlers defined in the template, or a @HostListener defined in a different Directive.

Implemented types

Constructors

BoundDirectiveEventAst(String memberName, String templateName, EventHandler handler, SourceSpan sourceSpan)

Properties

handler → EventHandler
final
hashCode → int
The hash code for this object.
no setterinherited
memberName → String
The name of the output member (field or getter) declared on the directive class.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sourceSpan → SourceSpan
The source span from which this node was parsed.
final
templateName → String
The name of the output, optionally declared by an output annotation.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited
visit<R, C, CO extends C>(TemplateAstVisitor<R, C> visitor, CO context) → R
Visit this node and possibly transform it.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited