EventHandler class

An event handler expression, with addition metadata.

Constructors

EventHandler(ASTWithSource expression, [CompileDirectiveMetadata? hostDirective])

Properties

expression → ASTWithSource
final
hashCode → int
The hash code for this object.
no setterinherited
hostDirective → CompileDirectiveMetadata?
An optional directive class.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited