RenderNodeHelpers class
Identifiers for RenderNode-based helpers (Phase 3: SSR template compiler). These replace direct DOM manipulation with an abstraction that works on both browser (DOM) and server (HTML string) contexts.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- addRenderEventListener → CompileIdentifierMetadata
-
addRenderEventListener(target, type, fn) -> adds event listener (SSR compatible)
final
- appendRenderChild → CompileIdentifierMetadata
-
appendRenderChild(parent, child) -> appends child to parent (SSR compatible)
final
- createRenderAnchor → CompileIdentifierMetadata
-
createRenderAnchor() -> creates comment anchor via renderFactory
final
- createRenderElement → CompileIdentifierMetadata
-
createRenderElement('div') -> creates element via renderFactory
final
- createRenderText → CompileIdentifierMetadata
-
createRenderText('content') -> creates text node via renderFactory
final