RenderNodeUpdateHelpers class
Identifiers for RenderNode-based update helpers (Phase 3: SSR template compiler). These replace direct DOM manipulation in the UPDATE phase with an abstraction that works on both browser (DOM) and server (HTML string) contexts.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
- updateRenderAttribute → CompileIdentifierMetadata
-
updateRenderAttribute(node, name, value) -> updates attribute on RenderNode or Element
final
- updateRenderClass → CompileIdentifierMetadata
-
updateRenderClass(node, className, enabled) -> updates class on RenderNode or Element
final
- updateRenderStyle → CompileIdentifierMetadata
-
updateRenderStyle(node, name, value) -> updates style on RenderNode or Element
final
- updateRenderTabIndex → CompileIdentifierMetadata
-
updateRenderTabIndex(node, value) -> updates tabIndex on RenderNode or Element
final