MissingDirectiveContext class
Constructors
-
MissingDirectiveContext(String elementName, List<
DirectiveAst> directives, Iterable<List< selectorsGroup, List<CssSelector> >CssSelector> matchedNgContentSelectors, List<CssSelector> skipValidationSelectors, {Set<String> attributeDeps = const {}})
Properties
-
attributeDeps
→ Set<
String> -
final
-
directives
→ List<
DirectiveAst> -
final
- elementName → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
matchedNgContentSelectors
→ List<
CssSelector> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
selectorsGroup
→ Iterable<
List< CssSelector> > -
final
-
skipValidationSelectors
→ List<
CssSelector> -
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited